# TMEXIO
Python framework for building SocketIO applications with typing, dependency injection and more

TBA

## Local Development
1. Clone the repository
2. Setup python (the library is made with python 3.12+)
3. Install poetry (should work with v1.8.2)
4. Install dependencies
5. Install pre-commit hooks

Commands to use:
```
pip install poetry==1.8.2
poetry install
pre-commit install
```
